(clj-deps id cmd)(clj-deps id {:keys [clj-img] :or {clj-img default-deps-img}} cmd)(clj-lein id cmds)(clj-lein id {:keys [clj-img] :or {clj-img default-lein-img}} cmds)Creates jobs that test and deploy a clojure library using deps.edn.
Creates jobs that test and deploy a clojure library using deps.edn.
(deps-publish
{:keys [publish-alias] :or {publish-alias ":jar:publish"} :as conf})(deps-test {:keys [test-alias artifact-id junit-file]
:or {test-alias ":test:junit"
artifact-id "test-junit"
junit-file "junit.xml"}
:as conf})Creates jobs that test and deploy a clojure library using leiningen.
Creates jobs that test and deploy a clojure library using leiningen.
(lein-test
{:keys [test-alias artifact-id junit-file]
:or {test-alias "test-junit" artifact-id "test-junit" junit-file "junit.xml"}
:as conf})(read-pom-version {:keys [pom-file] :or {pom-file "pom.xml"}} ctx)Given the step context, reads the pom.xml file from the configured location
and returns the version tag value.
Given the step context, reads the `pom.xml` file from the configured location and returns the version tag value.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |